Description Usage Arguments Author(s) Examples
View source: R/src_MostVariableRows.R
Find most variable rows of a numeric matrix. If rownames are present returns those, if not returns row index.
1 | MostVariableRows(counts, ntop = 1000, type = c("rv", "mgv"))
|
counts |
numeric matrix |
ntop |
number of most most variable rows to return |
type |
c("rv", "mgv") rv: selection by rowVars and mgv: selection based on
the scran function |
Alexander Toenges
1 2 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.